@@ -3,6 +3,7 @@ mod cmd;
 mod config;
 mod consts;
 mod template;
+mod validator;
 
 use anyhow::Result;
 use clap::{Parser, Subcommand};
@@ -21,14 +22,22 @@ struct Cli {
 
 #[derive(Subcommand)]
 enum Commands {
+    /// Create a template repository that manages dev.to articles
+    Start,
+
     /// Create a new article
     New { title: String },
+
+    /// Delete an unpublished article
+    Delete { title: String },
 }
 
 fn main() -> Result<()> {
     let cli = Cli::parse();
 
     match &cli.command {
+        Commands::Start => cmd::start::exec(),
         Commands::New { title } => cmd::new::exec(title, cli.devto_token),
+        Commands::Delete { title } => cmd::delete::exec(title, cli.devto_token),
     }
 }
